..  Copyright (C)  Brad Miller, David Ranum
    This work is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License. To view a copy of this license, visit http://creativecommons.org/licenses/by-nc-sa/4.0/.


Key Terms
---------

========================= ==================== ====================
             average case             constant          logarithmic
       benchmark analysis                cubic   order of magnitude
           Big O notation          exponential            quadratic
              brute force               linear      time complexity
             checking off           log linear           worst case
========================= ==================== ====================
